gendata <- function(n, m, stdev, distype = 1) {
	result <- NULL
	if(distype == 1) {
		result <- rnorm(n, 0, 1)
	} else if (distype == 2) {
		result <- rt(n, 3)
	} else if (distype == 3) {
		result <- rchisq(n, 4)
	} else {
		stop("The distype argument is not valid.")
	}
	result <- (result - mean(result)) / sd(result)
	
	# Find empirical mean and sd
	temp <- rnorm(n, m, stdev)
	result <- sd(temp) * result + mean(temp)
	return(result)
}

runrep <-
function(cond, seednum) {
    RNGkind("L'Ecuyer-CMRG")
    assign(".Random.seed", seednum[unlist(cond[4]),], envir = .GlobalEnv)
	b0 <- 0
	b1 <- unlist(cond[1])
	n <- unlist(cond[2])
	distype <- unlist(cond[3])
	x <- gendata(n, 0, 1, distype = distype)
	fy <- b0 + b1*x
	p <- exp(fy)/(1 + exp(fy))
	y <- rep(NA, n)
	for(w in 1:n) y[w] <- rbinom(1, 1, p[w])
	dat <- data.frame(x = x, y = y)
	out <- glm(y ~ x, data = dat, family = binomial(link = "logit"))
	sumout <- summary(out)
	return(sumout[["coefficients"]][2, c(1, 2, 4)])
}
